@@ -1,22 +1,24 @@
 use fugle::crawler;
 
 fn main() {
-    match crawler::intraday_chart("2884", "demo") {
+    let agent = crawler::IntradayBuilder::new().build();
+
+    match agent.chart("2884").call() {
         Ok(v) => println!("{:?}", v),
         Err(e) => println!("{}", e),
     }
 
-    match crawler::intraday_meta("2884", "demo") {
+    match agent.meta("2884").odd_lot(false).call() {
         Ok(v) => println!("{:?}", v),
         Err(e) => println!("{}", e),
     }
 
-    match crawler::intraday_quote("2884", "demo") {
+    match agent.quote("2884").odd_lot(true).call() {
         Ok(v) => println!("{:?}", v),
         Err(e) => println!("{}", e),
     }
 
-    match crawler::intraday_dealts("2884", "demo", 0, 0) {
+    match agent.dealts("2884").limit(10).call() {
         Ok(v) => println!("{:?}", v),
         Err(e) => println!("{}", e),
     }
